@@ -54,7 +54,7 @@ def addBikeshedVersion(doc):
         )
     except Exception:
         # Not in Bikeshed's repo, so instead grab from the datafile.
-        bikeshedVersion = doc.dataFile.fetch("bikeshed-version.txt", type="readonly", str=True).strip()
+        bikeshedVersion = doc.dataFile.fetch("bikeshed-version.txt", fileType="readonly", str=True).strip()
     h.appendChild(doc.head, h.E.meta({"name": "generator", "content": bikeshedVersion}))
 
 
@@ -282,7 +282,7 @@ def addBikeshedBoilerplate(doc):
 def addIndexSection(doc):
     hasLocalDfns = len(h.findAll(config.dfnElementsSelector, doc)) > 0
     hasExternalDfns = False
-    for spec, refs in doc.externalRefsUsed.items():
+    for refs in doc.externalRefsUsed.values():
         # refs is a {ref text => ref} table
         # but it can also have a _biblio key
         # to track biblio references.
@@ -564,7 +564,7 @@ def addIndexOfExternallyDefinedTerms(doc, container):
         }
         specLi = h.appendChild(
             ul,
-            h.E.li(h.E.a(attrs, "[", printableSpec, "]"), " defines the following terms:"),
+            h.E.li(h.E.a(attrs, "[", formatBiblioTerm(printableSpec), "]"), " defines the following terms:"),
         )
         termsUl = h.appendChild(specLi, h.E.ul())
         for _, refs in sorted(refGroups.items(), key=lambda x: x[0]):
@@ -1131,16 +1131,6 @@ def addReferencesSection(doc):
     if container is None:
         return
 
-    def formatBiblioTerm(linkText):
-        """
-        If the term is all uppercase, leave it like that.
-        If it's all lowercase, uppercase it.
-        If it's mixed case, leave it like that.
-        """
-        if linkText.islower():
-            return linkText.upper()
-        return linkText
-
     h.appendChild(
         container,
         h.E.h2({"class": "no-num no-ref", "id": h.safeID(doc, "references")}, "References"),
@@ -1223,3 +1213,14 @@ def addIssuesSection(doc):
         del idel.attrib["id"]
     for dfnel in h.findAll(config.dfnElementsSelector, container):
         dfnel.tag = "span"
+
+
+def formatBiblioTerm(linkText: str) -> str:
+    """
+    If the term is all uppercase, leave it like that.
+    If it's all lowercase, uppercase it.
+    If it's mixed case, leave it like that.
+    """
+    if linkText.islower():
+        return linkText.upper()
+    return linkText
