@@ -2,10 +2,8 @@ import copy
 import re
 from collections import defaultdict
 
-from .. import config, constants
-from ..messages import linkerror
-from .RefWrapper import RefWrapper
-from .utils import *
+from .. import config, constants, messages as m, retrieve
+from . import utils, RefWrapper
 
 
 class RefSource:
@@ -27,7 +25,7 @@ class RefSource:
 
     def __init__(self, source, specs=None, ignored=None, replaced=None, fileRequester=None):
         if fileRequester is None:
-            self.dataFile = config.defaultRequester
+            self.dataFile = retrieve.defaultRequester
         else:
             self.dataFile = fileRequester
 
@@ -118,13 +116,13 @@ class RefSource:
             # Turns a dict of arrays of refs into an iterator of refs
             for key, group in self.fetchAllRefs():
                 for ref in group:
-                    yield RefWrapper(key, ref)
+                    yield RefWrapper.RefWrapper(key, ref)
 
         def textRefsIterator(texts):
             # Same as above, but only grabs those keyed to a given text
             for text in texts:
                 for ref in self.fetchRefs(text):
-                    yield RefWrapper(text, ref)
+                    yield RefWrapper.RefWrapper(text, ref)
 
         def forRefsIterator(targetFors):
             # Same as above, but only grabs those for certain values
@@ -133,14 +131,14 @@ class RefSource:
             for for_ in targetFors:
                 for text in self.fors[for_]:
                     for ref in self.fetchRefs(text):
-                        yield RefWrapper(text, ref)
+                        yield RefWrapper.RefWrapper(text, ref)
 
         # Set up the initial list of refs to query
         if text:
             if exact:
                 refs = list(textRefsIterator([text]))
             else:
-                textsToSearch = list(linkTextVariations(text, linkType))
+                textsToSearch = list(utils.linkTextVariations(text, linkType))
                 if text.endswith("()") and text in self.methods:
                     textsToSearch += list(self.methods[text].keys())
                 if (linkType is None or linkType in config.lowercaseTypes) and text.lower() != text:
@@ -160,7 +158,7 @@ class RefSource:
                 linkTypes = list(config.linkTypeToDfnType[linkType])
             else:
                 if error:
-                    linkerror(f"Unknown link type '{linkType}'.")
+                    m.linkerror(f"Unknown link type '{linkType}'.")
                 return [], "type"
             refs = [x for x in refs if x.type in linkTypes]
         if not refs:
@@ -258,7 +256,7 @@ class RefSource:
         if ignoreObsoletes and not spec:
             # Remove any ignored or obsoleted specs
             # If you specified the spec, don't filter things - you know what you're doing.
-            refs = filterObsoletes(refs, replacedSpecs=self.replacedSpecs, ignoredSpecs=self.ignoredSpecs)
+            refs = utils.filterObsoletes(refs, replacedSpecs=self.replacedSpecs, ignoredSpecs=self.ignoredSpecs)
         if not refs:
             return refs, "ignored-specs"
 
@@ -279,7 +277,7 @@ class RefSource:
             # only use the latest level.
             # If generating for a snapshot, prefer the latest snapshot level,
             # unless that doesn't exist, in which case just prefer the latest level.
-            refs = filterOldVersions(refs, status=status or statusHint)
+            refs = utils.filterOldVersions(refs, status=status or statusHint)
 
         return refs, None
 
