@@ -5,39 +5,44 @@ from __future__ import annotations
 import sys
 from typing import (
     Any,
+    cast,
     DefaultDict,
+    Deque,
     Dict,
+    Generator,
     Iterable,
     Iterator,
     List,
     Mapping,
     Optional,
+    overload,
     Sequence,
     Set,
     Tuple,
+    TYPE_CHECKING,
     TypeVar,
     Union,
-    TYPE_CHECKING,
-    cast,
-    overload,
 )
 
 from lxml import etree
 from typing_extensions import Literal, TypeAlias
 
 
-ElementT = etree._Element  # pylint: disable=protected-access
-DocumentT = etree._ElementTree  # pylint: disable=protected-access
-NodeT = Union[str, ElementT]
+ElementT: TypeAlias = etree._Element  # pylint: disable=protected-access
+DocumentT: TypeAlias = etree._ElementTree  # pylint: disable=protected-access
+NodeT: TypeAlias = Union[str, ElementT]
 
 # Can't actually do recursive types yet :(
 # Get as close as possible, but let lists be Any
-NodesT = Union[NodeT, List]
+NodesT: TypeAlias = Union[NodeT, List]
 
 
 if TYPE_CHECKING:
     if "Spec" not in sys.modules:
         from .Spec import Spec  # pylint: disable=cyclic-import
     SpecT = Spec
-else:
-    SpecT = None
+
+if TYPE_CHECKING:
+    from . import biblio  # pylint: disable=cyclic-import
+
+    BiblioStorageT: TypeAlias = DefaultDict[str, List[biblio.BiblioEntry]]
