@@ -1,16 +1,4 @@
-from ..h import (
-    E,
-    addClass,
-    appendChild,
-    clearContents,
-    findAll,
-    removeNode,
-    removeAttr,
-    textContent,
-    parseHTML,
-)
-from ..messages import *
-from .. import config
+from .. import config, h, messages as m
 
 
 def processWptElements(doc):
@@ -20,7 +8,7 @@ def processWptElements(doc):
     atLeastOneVisibleTest = False
     testData = None
     # <wpt> elements
-    wptElements = findAll("wpt", doc)
+    wptElements = h.findAll("wpt", doc)
     seenTestNames = set()
     prevEl = None
     for el in wptElements:
@@ -31,46 +19,46 @@ def processWptElements(doc):
         testNames = testNamesFromEl(el, pathPrefix=pathPrefix)
         for testName in testNames:
             if testName not in testData:
-                die(f"Couldn't find WPT test '{testName}' - did you misspell something?", el=el)
+                m.die(f"Couldn't find WPT test '{testName}' - did you misspell something?", el=el)
                 continue
             seenTestNames.add(testName)
             if atLeastOneVisibleTest is False and el.get("hidden") is None:
                 atLeastOneVisibleTest = True
         if el.get("hidden") is not None:
-            removeNode(el)
+            h.removeNode(el)
         else:
             title = el.get("title")
             titleLang = el.get("lang")
             titleDir = el.get("dir")
             if prevEl is not None and prevEl.getnext() is el and (prevEl.tail is None or prevEl.tail.strip() == ""):
                 appendTestList(prevEl, testNames, testData, title, titleLang, titleDir)
-                removeNode(el)
+                h.removeNode(el)
             else:
                 createHTML(doc, el, testNames, testData, title, titleLang, titleDir)
                 prevEl = el
 
     # <wpt-rest> elements
-    wptRestElements = findAll("wpt-rest", doc)
+    wptRestElements = h.findAll("wpt-rest", doc)
     if wptRestElements and testData is None:
         testData = loadTestData(doc)
     if len(wptRestElements) > 1:
-        die(f"Only one <wpt-rest> element allowed per document, you have {len(wptRestElements)}.")
+        m.die(f"Only one <wpt-rest> element allowed per document, you have {len(wptRestElements)}.")
         wptRestElements = wptRestElements[0:1]
     elif len(wptRestElements) == 1:
         localPrefix = wptRestElements[0].get("pathprefix")
         if localPrefix is not None:
             pathPrefix = localPrefix
         if pathPrefix is None:
-            die("Can't use <wpt-rest> without either a pathprefix=" " attribute or a 'WPT Path Prefix' metadata.")
+            m.die("Can't use <wpt-rest> without either a pathprefix=" " attribute or a 'WPT Path Prefix' metadata.")
             return
         prefixedNames = [p for p in testData if prefixInPath(pathPrefix, p) and p not in seenTestNames]
         if len(prefixedNames) == 0:
-            die(f"Couldn't find any tests with the path prefix '{pathPrefix}'.")
+            m.die(f"Couldn't find any tests with the path prefix '{pathPrefix}'.")
             return
         atLeastOneElement = True
         atLeastOneVisibleTest = True
         createHTML(doc, wptRestElements[0], prefixedNames, testData)
-        warn(
+        m.warn(
             "<wpt-rest> is intended for debugging only. Move the tests to <wpt> elements next to what they're testing."
         )
     else:
@@ -86,9 +74,9 @@ def processWptElements(doc):
             pathPrefix = "/" + pathPrefix
         if pathPrefix != "/":
             doc.md.otherMetadata["Test Suite"].append(
-                E.dd(
+                h.E.dd(
                     {"class": "wpt-overview"},
-                    E.a(
+                    h.E.a(
                         {"href": f"https://wpt.fyi/results{pathPrefix}"},
                         f"https://wpt.fyi/results{pathPrefix}",
                     ),
@@ -105,39 +93,39 @@ def processWptElements(doc):
 
 def createHTML(doc, blockEl, testNames, testData, title=None, titleLang=None, titleDir=None):
     if doc.md.wptDisplay == "none":
-        removeNode(blockEl)
+        h.removeNode(blockEl)
     elif doc.md.wptDisplay in ("inline", "open", "closed"):
         blockEl.tag = "details"
-        addClass(blockEl, "wpt-tests-block")
-        removeAttr(blockEl, "pathprefix")
-        removeAttr(blockEl, "title")
+        h.addClass(blockEl, "wpt-tests-block")
+        h.removeAttr(blockEl, "pathprefix")
+        h.removeAttr(blockEl, "title")
         blockEl.set("lang", "en")
         blockEl.set("dir", "ltr")
         if doc.md.wptDisplay in ("open", "inline"):
             blockEl.set("open", "")
-        clearContents(blockEl)
-        testSummaryEl = E.summary("Tests")
-        appendChild(blockEl, testSummaryEl)
+        h.clearContents(blockEl)
+        testSummaryEl = h.E.summary("Tests")
+        h.appendChild(blockEl, testSummaryEl)
         appendTestList(blockEl, testNames, testData, title, titleLang, titleDir)
     else:
-        die("Programming error, uncaught WPT Display value in createHTML.")
+        m.die("Programming error, uncaught WPT Display value in createHTML.")
 
 
 def appendTestList(blockEl, testNames, testData, title=None, titleLang=None, titleDir=None):
     if title:
-        titleEl = E.p(
+        titleEl = h.E.p(
             {
                 "lang": titleLang,
                 "dir": titleDir,
             },
-            parseHTML(title),
+            h.parseHTML(title),
         )
-        appendChild(blockEl, titleEl)
-    testListEl = E.ul({"class": "wpt-tests-list"})
-    appendChild(blockEl, testListEl)
+        h.appendChild(blockEl, titleEl)
+    testListEl = h.E.ul({"class": "wpt-tests-list"})
+    h.appendChild(blockEl, testListEl)
     for testName in testNames:
         if testName not in testData:
-            warn(f"Cannot find '{testName}' in the test data.")
+            m.warn(f"Cannot find '{testName}' in the test data.")
             continue
         if ".https." in testName or ".serviceworker." in testName:
             liveTestScheme = "https"
@@ -146,9 +134,9 @@ def appendTestList(blockEl, testNames, testData, title=None, titleLang=None, tit
         _, _, lastNameFragment = testName.rpartition("/")
         testType = testData[testName]
         if testType in ["crashtest", "print-reftest", "reftest", "testharness"]:
-            singleTestEl = E.li(
+            singleTestEl = h.E.li(
                 {"class": "wpt-test"},
-                E.a(
+                h.E.a(
                     {
                         "title": testName,
                         "href": "https://wpt.fyi/results/" + testName,
@@ -157,38 +145,38 @@ def appendTestList(blockEl, testNames, testData, title=None, titleLang=None, tit
                     lastNameFragment,
                 ),
                 " ",
-                E.a(
+                h.E.a(
                     {
                         "href": f"{liveTestScheme}://wpt.live/{testName}",
                         "class": "wpt-live",
                     },
-                    E.small("(live test)"),
+                    h.E.small("(live test)"),
                 ),
                 " ",
-                E.a(
+                h.E.a(
                     {
                         "href": "https://github.com/web-platform-tests/wpt/blob/master/" + testName,
                         "class": "wpt-source",
                     },
-                    E.small("(source)"),
+                    h.E.small("(source)"),
                 ),
             )
         elif testType in ["manual", "visual"]:
-            singleTestEl = E.li(
+            singleTestEl = h.E.li(
                 {"class": "wpt-test"},
-                E.span({"class": "wpt-name"}, lastNameFragment, f" ({testType} test) "),
-                E.a(
+                h.E.span({"class": "wpt-name"}, lastNameFragment, f" ({testType} test) "),
+                h.E.a(
                     {
                         "href": "https://github.com/web-platform-tests/wpt/blob/master/" + testName,
                         "class": "wpt-source",
                     },
-                    E.small("(source)"),
+                    h.E.small("(source)"),
                 ),
             )
         elif testType in ["wdspec"]:
-            singleTestEl = E.li(
+            singleTestEl = h.E.li(
                 {"class": "wpt-test"},
-                E.a(
+                h.E.a(
                     {
                         "href": "https://wpt.fyi/results/" + testName,
                         "class": "wpt-name",
@@ -196,22 +184,22 @@ def appendTestList(blockEl, testNames, testData, title=None, titleLang=None, tit
                     lastNameFragment,
                 ),
                 " ",
-                E.a(
+                h.E.a(
                     {
                         "href": "https://github.com/web-platform-tests/wpt/blob/master/" + testName,
                         "class": "wpt-source",
                     },
-                    E.small("(source)"),
+                    h.E.small("(source)"),
                 ),
             )
         else:
-            warn(
+            m.warn(
                 f"Programming error, the test {testName} is of type {testType}, which I don't know how to render. Please report this!"
             )
             continue
-        appendChild(testListEl, singleTestEl)
+        h.appendChild(testListEl, singleTestEl)
     if title:
-        appendChild(blockEl, E.hr())
+        h.appendChild(blockEl, h.E.hr())
 
 
 def testNamesFromEl(el, pathPrefix=None):
@@ -219,7 +207,7 @@ def testNamesFromEl(el, pathPrefix=None):
     localPrefix = el.get("pathprefix")
     if localPrefix is not None:
         pathPrefix = localPrefix
-    for name in [x.strip() for x in textContent(el).split("\n")]:
+    for name in [x.strip() for x in h.textContent(el).split("\n")]:
         if name == "":
             continue
         testName = prefixPlusPath(pathPrefix, name)
@@ -264,7 +252,7 @@ def checkForOmittedTests(pathPrefix, testData, seenTestNames):
                 unseenTests.append(testPath)
     if unseenTests:
         numTests = len(unseenTests)
-        warn(
+        m.warn(
             f"There are {numTests} WPT tests underneath your path prefix '{pathPrefix}' that aren't in your document and must be added. (Use a <wpt hidden> if you don't actually want them in your document.)\n"
             + "\n".join("  " + path for path in sorted(unseenTests)),
         )
